@@ -1,29 +1,16 @@
-/***************************************************************************
- *   Copyright (C) 2007-2009 by Shawn Starr <shawn.starr@rogers.com>       *
- *   Copyright (C) 2012 by Luís Gabriel Lima <lampih@gmail.com>            *
- *   Copyright (C) 2017-2018 Friedrich W. H. Kossebau <kossebau@kde.org>   *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2007-2009 Shawn Starr <shawn.starr@rogers.com>
+ *   SPDX-FileCopyrightText: 2012 Luís Gabriel Lima <lampih@gmail.com>
+ *   SPDX-FileCopyrightText: 2017-2018 Friedrich W. H. Kossebau <kossebau@kde.org>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #ifndef WEATHERAPPLET_H
 #define WEATHERAPPLET_H
 
-#include <KUnitConversion/Unit>
 #include <KUnitConversion/Converter>
+#include <KUnitConversion/Unit>
 
 #include <Plasma/Applet>
 
@@ -74,23 +61,63 @@ public: // QML config control API
     /**
      * @param configChanges config key-value entries which have changed
      */
-    Q_INVOKABLE void saveConfig(const QVariantMap& configChanges);
+    Q_INVOKABLE void saveConfig(const QVariantMap &configChanges);
 
 public:
-    QString source() const     { return m_source; }
-    int updateInterval() const { return m_updateInterval; }
+    QString source() const
+    {
+        return m_source;
+    }
 
-    int displayTemperatureUnit() const { return m_displayTemperatureUnit.id(); }
-    int displaySpeedUnit() const       { return m_displaySpeedUnit.id(); }
-    int displayPressureUnit() const    { return m_displayPressureUnit.id(); }
-    int displayVisibilityUnit() const  { return m_displayVisibilityUnit.id(); }
+    int updateInterval() const
+    {
+        return m_updateInterval;
+    }
 
-    bool temperatureShownInTooltip() const  { return m_temperatureShownInTooltip; }
-    bool windShownInTooltip() const         { return m_windShownInTooltip; }
-    bool pressureShownInTooltip() const     { return m_pressureShownInTooltip; }
-    bool humidityShownInTooltip() const     { return m_humidityShownInTooltip; }
+    int displayTemperatureUnit() const
+    {
+        return m_displayTemperatureUnit.id();
+    }
 
-    bool temperatureShownInCompactMode() const  { return m_temperatureShownInCompactMode; }
+    int displaySpeedUnit() const
+    {
+        return m_displaySpeedUnit.id();
+    }
+
+    int displayPressureUnit() const
+    {
+        return m_displayPressureUnit.id();
+    }
+
+    int displayVisibilityUnit() const
+    {
+        return m_displayVisibilityUnit.id();
+    }
+
+    bool temperatureShownInTooltip() const
+    {
+        return m_temperatureShownInTooltip;
+    }
+
+    bool windShownInTooltip() const
+    {
+        return m_windShownInTooltip;
+    }
+
+    bool pressureShownInTooltip() const
+    {
+        return m_pressureShownInTooltip;
+    }
+
+    bool humidityShownInTooltip() const
+    {
+        return m_humidityShownInTooltip;
+    }
+
+    bool temperatureShownInCompactMode() const
+    {
+        return m_temperatureShownInCompactMode;
+    }
 
 Q_SIGNALS:
     void configurationChanged();
@@ -107,7 +134,7 @@ Q_SIGNALS:
     void temperatureShownInCompactModeChanged();
 
 private:
-    KUnitConversion::Unit unit(const QString& unit);
+    KUnitConversion::Unit unit(const QString &unit);
 
 private:
     KUnitConversion::Converter m_converter;
