@@ -326,7 +326,8 @@ const QStringList &ComicProviderWrapper::extensions() const
         QStringList list;
         QString wildcards;
 
-        foreach (const QString &interpretername, Kross::Manager::self().interpreters()) {
+        const auto interpreters = Kross::Manager::self().interpreters();
+        for (const QString &interpretername : interpreters) {
             info = Kross::Manager::self().interpreterInfo(interpretername);
             wildcards = info->wildcard();
             wildcards.remove(QLatin1Char('*'));
@@ -717,7 +718,7 @@ void ComicProviderWrapper::pageError(int id, const QString &message)
     --mRequests;
     callFunction(QLatin1String("pageError"), QVariantList() << id << message);
     if (!functionCalled()) {
-        emit mProvider->error(mProvider);
+        Q_EMIT mProvider->error(mProvider);
     }
 }
 
@@ -742,20 +743,20 @@ void ComicProviderWrapper::finished() const
     qDebug() << QString::fromLatin1("Last Identifier").leftJustified(22, QLatin1Char('.')) << mLastIdentifier;
     qDebug() << QString::fromLatin1("Next Identifier").leftJustified(22, QLatin1Char('.')) << mNextIdentifier;
     qDebug() << QString::fromLatin1("Previous Identifier").leftJustified(22, QLatin1Char('.')) << mPreviousIdentifier;
-    emit mProvider->finished(mProvider);
+    Q_EMIT mProvider->finished(mProvider);
 }
 
 void ComicProviderWrapper::error() const
 {
-    emit mProvider->error(mProvider);
+    Q_EMIT mProvider->error(mProvider);
 }
 
 void ComicProviderWrapper::requestPage(const QString &url, int id, const QVariantMap &infos)
 {
     QMap<QString, QString> map;
 
-    foreach (const QString &key, infos.keys()) {
-        map[key] = infos[key].toString();
+    for (auto it = infos.begin(), end = infos.end(); it != end; ++it) {
+        map[it.key()] = it.value().toString();
     }
     mProvider->requestPage(QUrl(url), id, map);
     ++mRequests;
@@ -765,8 +766,8 @@ void ComicProviderWrapper::requestRedirectedUrl(const QString &url, int id, cons
 {
     QMap<QString, QString> map;
 
-    foreach (const QString &key, infos.keys()) {
-        map[key] = infos[key].toString();
+    for (auto it = infos.begin(), end = infos.end(); it != end; ++it) {
+        map[it.key()] = it.value().toString();
     }
     mProvider->requestRedirectedUrl(QUrl(url), id, map);
     ++mRequests;
